pub struct BusyState {
pub creating_account: bool,
pub restoring_session: bool,
pub linking_device: bool,
pub creating_chat: bool,
pub creating_group: bool,
pub sending_message: bool,
pub updating_roster: bool,
pub updating_group: bool,
pub creating_invite: bool,
pub accepting_invite: bool,
pub syncing_network: bool,
pub uploading_attachment: bool,
}Fields
creating_account: boolrestoring_session: boollinking_device: boolcreating_chat: boolcreating_group: boolsending_message: boolupdating_roster: boolupdating_group: boolcreating_invite: boolaccepting_invite: boolsyncing_network: booluploading_attachment: boolTrait Implementations
Sourceimpl<UT> ConvertError<UT> for BusyState
impl<UT> ConvertError<UT> for BusyState
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl<UT> FfiConverter<UT> for BusyState
impl<UT> FfiConverter<UT> for BusyState
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a MetadataBuffer.
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl<UT> LiftReturn<UT> for BusyState
impl<UT> LiftReturn<UT> for BusyState
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
Sourcefn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
Sourcefn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
Sourcefn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> LowerError<UT> for BusyState
impl<UT> LowerError<UT> for BusyState
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for BusyState
impl<UT> LowerReturn<UT> for BusyState
Sourcetype ReturnType = <BusyState as Lower<UT>>::FfiType
type ReturnType = <BusyState as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
Sourcefn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
impl Eq for BusyState
impl StructuralPartialEq for BusyState