pub struct ChatThreadSnapshot {Show 13 fields
pub chat_id: String,
pub kind: ChatKind,
pub display_name: String,
pub subtitle: Option<String>,
pub picture_url: Option<String>,
pub member_count: u64,
pub last_message_preview: Option<String>,
pub last_message_at_secs: Option<u64>,
pub last_message_is_outgoing: Option<bool>,
pub last_message_delivery: Option<DeliveryState>,
pub unread_count: u64,
pub is_typing: bool,
pub is_muted: bool,
}Fields
chat_id: Stringkind: ChatKinddisplay_name: Stringsubtitle: Option<String>picture_url: Option<String>member_count: u64last_message_preview: Option<String>last_message_at_secs: Option<u64>last_message_is_outgoing: Option<bool>last_message_delivery: Option<DeliveryState>unread_count: u64is_typing: boolis_muted: boolTrait Implementations
Sourceimpl Clone for ChatThreadSnapshot
impl Clone for ChatThreadSnapshot
Sourcefn clone(&self) -> ChatThreadSnapshot
fn clone(&self) -> ChatThreadSnapshot
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<UT> ConvertError<UT> for ChatThreadSnapshot
impl<UT> ConvertError<UT> for ChatThreadSnapshot
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl Debug for ChatThreadSnapshot
impl Debug for ChatThreadSnapshot
Sourceimpl<UT> FfiConverter<UT> for ChatThreadSnapshot
impl<UT> FfiConverter<UT> for ChatThreadSnapshot
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a MetadataBuffer.
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl<UT> Lift<UT> for ChatThreadSnapshot
impl<UT> Lift<UT> for ChatThreadSnapshot
Sourceimpl<UT> LiftRef<UT> for ChatThreadSnapshot
impl<UT> LiftRef<UT> for ChatThreadSnapshot
Sourceimpl<UT> LiftReturn<UT> for ChatThreadSnapshot
impl<UT> LiftReturn<UT> for ChatThreadSnapshot
Sourcetype ReturnType = <ChatThreadSnapshot as Lift<UT>>::FfiType
type ReturnType = <ChatThreadSnapshot as Lift<UT>>::FfiType
FFI return type for trait interfaces
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
Sourcefn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
Sourcefn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
Sourcefn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> Lower<UT> for ChatThreadSnapshot
impl<UT> Lower<UT> for ChatThreadSnapshot
type FfiType = <ChatThreadSnapshot as FfiConverter<UT>>::FfiType
fn lower(obj: Self) -> Self::FfiType
fn write(obj: Self, buf: &mut Vec<u8>)
Sourcefn lower_into_rust_buffer(obj: Self) -> RustBuffer
fn lower_into_rust_buffer(obj: Self) -> RustBuffer
Convenience method
Sourceimpl<UT> LowerError<UT> for ChatThreadSnapshot
impl<UT> LowerError<UT> for ChatThreadSnapshot
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for ChatThreadSnapshot
impl<UT> LowerReturn<UT> for ChatThreadSnapshot
Sourcetype ReturnType = <ChatThreadSnapshot as Lower<UT>>::FfiType
type ReturnType = <ChatThreadSnapshot as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
Sourcefn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
Sourceimpl PartialEq for ChatThreadSnapshot
impl PartialEq for ChatThreadSnapshot
Sourceimpl<UT> TypeId<UT> for ChatThreadSnapshot
impl<UT> TypeId<UT> for ChatThreadSnapshot
impl Eq for ChatThreadSnapshot
impl StructuralPartialEq for ChatThreadSnapshot