pub struct FfiPerfCountersSnapshot {
pub state: u64,
pub dispatch: u64,
pub search: u64,
pub ingest_nearby_event_json: u64,
pub export_support_bundle_json: u64,
pub peer_profile_debug: u64,
pub mutual_groups: u64,
pub prepare_for_suspend: u64,
}Fields
state: u64dispatch: u64search: u64ingest_nearby_event_json: u64export_support_bundle_json: u64peer_profile_debug: u64mutual_groups: u64prepare_for_suspend: u64Trait Implementations
Sourceimpl Clone for FfiPerfCountersSnapshot
impl Clone for FfiPerfCountersSnapshot
Sourcefn clone(&self) -> FfiPerfCountersSnapshot
fn clone(&self) -> FfiPerfCountersSnapshot
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<UT> ConvertError<UT> for FfiPerfCountersSnapshot
impl<UT> ConvertError<UT> for FfiPerfCountersSnapshot
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl Debug for FfiPerfCountersSnapshot
impl Debug for FfiPerfCountersSnapshot
Sourceimpl Default for FfiPerfCountersSnapshot
impl Default for FfiPerfCountersSnapshot
Sourcefn default() -> FfiPerfCountersSnapshot
fn default() -> FfiPerfCountersSnapshot
Returns the “default value” for a type. Read more
Sourceimpl<UT> FfiConverter<UT> for FfiPerfCountersSnapshot
impl<UT> FfiConverter<UT> for FfiPerfCountersSnapshot
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a MetadataBuffer.
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl<UT> Lift<UT> for FfiPerfCountersSnapshot
impl<UT> Lift<UT> for FfiPerfCountersSnapshot
Sourceimpl<UT> LiftRef<UT> for FfiPerfCountersSnapshot
impl<UT> LiftRef<UT> for FfiPerfCountersSnapshot
Sourceimpl<UT> LiftReturn<UT> for FfiPerfCountersSnapshot
impl<UT> LiftReturn<UT> for FfiPerfCountersSnapshot
Sourcetype ReturnType = <FfiPerfCountersSnapshot as Lift<UT>>::FfiType
type ReturnType = <FfiPerfCountersSnapshot as Lift<UT>>::FfiType
FFI return type for trait interfaces
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
Sourcefn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
Sourcefn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
Sourcefn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> Lower<UT> for FfiPerfCountersSnapshot
impl<UT> Lower<UT> for FfiPerfCountersSnapshot
type FfiType = <FfiPerfCountersSnapshot as FfiConverter<UT>>::FfiType
fn lower(obj: Self) -> Self::FfiType
fn write(obj: Self, buf: &mut Vec<u8>)
Sourcefn lower_into_rust_buffer(obj: Self) -> RustBuffer
fn lower_into_rust_buffer(obj: Self) -> RustBuffer
Convenience method
Sourceimpl<UT> LowerError<UT> for FfiPerfCountersSnapshot
impl<UT> LowerError<UT> for FfiPerfCountersSnapshot
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for FfiPerfCountersSnapshot
impl<UT> LowerReturn<UT> for FfiPerfCountersSnapshot
Sourcetype ReturnType = <FfiPerfCountersSnapshot as Lower<UT>>::FfiType
type ReturnType = <FfiPerfCountersSnapshot as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
Sourcefn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
Sourceimpl PartialEq for FfiPerfCountersSnapshot
impl PartialEq for FfiPerfCountersSnapshot
Sourcefn eq(&self, other: &FfiPerfCountersSnapshot) -> bool
fn eq(&self, other: &FfiPerfCountersSnapshot) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl<UT> TypeId<UT> for FfiPerfCountersSnapshot
impl<UT> TypeId<UT> for FfiPerfCountersSnapshot
impl Eq for FfiPerfCountersSnapshot
impl StructuralPartialEq for FfiPerfCountersSnapshot