pub struct IrisDesktopUpdateResult {
pub ok: bool,
pub error: Option<String>,
pub available: bool,
pub current_version: String,
pub latest_version: String,
pub tag: String,
pub asset: String,
pub source: String,
pub verified: bool,
pub url: Option<String>,
pub path: Option<String>,
}Fields
ok: boolerror: Option<String>available: boolcurrent_version: Stringlatest_version: Stringtag: Stringasset: Stringsource: Stringverified: boolurl: Option<String>path: Option<String>Trait Implementations
Sourceimpl Clone for IrisDesktopUpdateResult
impl Clone for IrisDesktopUpdateResult
Sourcefn clone(&self) -> IrisDesktopUpdateResult
fn clone(&self) -> IrisDesktopUpdateResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<UT> ConvertError<UT> for IrisDesktopUpdateResult
impl<UT> ConvertError<UT> for IrisDesktopUpdateResult
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl Debug for IrisDesktopUpdateResult
impl Debug for IrisDesktopUpdateResult
impl Eq for IrisDesktopUpdateResult
Sourceimpl<UT> FfiConverter<UT> for IrisDesktopUpdateResult
impl<UT> FfiConverter<UT> for IrisDesktopUpdateResult
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a MetadataBuffer.
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl<UT> Lift<UT> for IrisDesktopUpdateResult
impl<UT> Lift<UT> for IrisDesktopUpdateResult
Sourceimpl<UT> LiftRef<UT> for IrisDesktopUpdateResult
impl<UT> LiftRef<UT> for IrisDesktopUpdateResult
Sourceimpl<UT> LiftReturn<UT> for IrisDesktopUpdateResult
impl<UT> LiftReturn<UT> for IrisDesktopUpdateResult
Sourcetype ReturnType = <IrisDesktopUpdateResult as Lift<UT>>::FfiType
type ReturnType = <IrisDesktopUpdateResult as Lift<UT>>::FfiType
FFI return type for trait interfaces
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
Sourcefn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
Sourcefn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
Sourcefn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> Lower<UT> for IrisDesktopUpdateResult
impl<UT> Lower<UT> for IrisDesktopUpdateResult
type FfiType = <IrisDesktopUpdateResult as FfiConverter<UT>>::FfiType
fn lower(obj: Self) -> Self::FfiType
fn write(obj: Self, buf: &mut Vec<u8>)
Sourcefn lower_into_rust_buffer(obj: Self) -> RustBuffer
fn lower_into_rust_buffer(obj: Self) -> RustBuffer
Convenience method
Sourceimpl<UT> LowerError<UT> for IrisDesktopUpdateResult
impl<UT> LowerError<UT> for IrisDesktopUpdateResult
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for IrisDesktopUpdateResult
impl<UT> LowerReturn<UT> for IrisDesktopUpdateResult
Sourcetype ReturnType = <IrisDesktopUpdateResult as Lower<UT>>::FfiType
type ReturnType = <IrisDesktopUpdateResult as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
Sourcefn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
Sourceimpl PartialEq for IrisDesktopUpdateResult
impl PartialEq for IrisDesktopUpdateResult
Sourcefn eq(&self, other: &IrisDesktopUpdateResult) -> bool
fn eq(&self, other: &IrisDesktopUpdateResult) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for IrisDesktopUpdateResult
Sourceimpl<UT> TypeId<UT> for IrisDesktopUpdateResult
impl<UT> TypeId<UT> for IrisDesktopUpdateResult