pub struct MessageDeliveryTraceSnapshot {
pub outer_event_ids: Vec<String>,
pub pending_relay_event_ids: Vec<String>,
pub queued_protocol_targets: Vec<String>,
pub target_device_ids: Vec<String>,
pub transport_channels: Vec<String>,
pub last_transport_error: Option<String>,
}Fields
outer_event_ids: Vec<String>pending_relay_event_ids: Vec<String>queued_protocol_targets: Vec<String>target_device_ids: Vec<String>transport_channels: Vec<String>last_transport_error: Option<String>Trait Implementations
Sourceimpl Clone for MessageDeliveryTraceSnapshot
impl Clone for MessageDeliveryTraceSnapshot
Sourcefn clone(&self) -> MessageDeliveryTraceSnapshot
fn clone(&self) -> MessageDeliveryTraceSnapshot
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<UT> ConvertError<UT> for MessageDeliveryTraceSnapshot
impl<UT> ConvertError<UT> for MessageDeliveryTraceSnapshot
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl Debug for MessageDeliveryTraceSnapshot
impl Debug for MessageDeliveryTraceSnapshot
Sourceimpl Default for MessageDeliveryTraceSnapshot
impl Default for MessageDeliveryTraceSnapshot
Sourcefn default() -> MessageDeliveryTraceSnapshot
fn default() -> MessageDeliveryTraceSnapshot
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for MessageDeliveryTraceSnapshotwhere
MessageDeliveryTraceSnapshot: Default,
impl<'de> Deserialize<'de> for MessageDeliveryTraceSnapshotwhere
MessageDeliveryTraceSnapshot: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<UT> FfiConverter<UT> for MessageDeliveryTraceSnapshot
impl<UT> FfiConverter<UT> for MessageDeliveryTraceSnapshot
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a MetadataBuffer.
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl<UT> Lift<UT> for MessageDeliveryTraceSnapshot
impl<UT> Lift<UT> for MessageDeliveryTraceSnapshot
Sourceimpl<UT> LiftRef<UT> for MessageDeliveryTraceSnapshot
impl<UT> LiftRef<UT> for MessageDeliveryTraceSnapshot
Sourceimpl<UT> LiftReturn<UT> for MessageDeliveryTraceSnapshot
impl<UT> LiftReturn<UT> for MessageDeliveryTraceSnapshot
Sourcetype ReturnType = <MessageDeliveryTraceSnapshot as Lift<UT>>::FfiType
type ReturnType = <MessageDeliveryTraceSnapshot as Lift<UT>>::FfiType
FFI return type for trait interfaces
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
Sourcefn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
Sourcefn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
Sourcefn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> Lower<UT> for MessageDeliveryTraceSnapshot
impl<UT> Lower<UT> for MessageDeliveryTraceSnapshot
type FfiType = <MessageDeliveryTraceSnapshot as FfiConverter<UT>>::FfiType
fn lower(obj: Self) -> Self::FfiType
fn write(obj: Self, buf: &mut Vec<u8>)
Sourcefn lower_into_rust_buffer(obj: Self) -> RustBuffer
fn lower_into_rust_buffer(obj: Self) -> RustBuffer
Convenience method
Sourceimpl<UT> LowerError<UT> for MessageDeliveryTraceSnapshot
impl<UT> LowerError<UT> for MessageDeliveryTraceSnapshot
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for MessageDeliveryTraceSnapshot
impl<UT> LowerReturn<UT> for MessageDeliveryTraceSnapshot
Sourcetype ReturnType = <MessageDeliveryTraceSnapshot as Lower<UT>>::FfiType
type ReturnType = <MessageDeliveryTraceSnapshot as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
Sourcefn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
Sourceimpl PartialEq for MessageDeliveryTraceSnapshot
impl PartialEq for MessageDeliveryTraceSnapshot
Sourcefn eq(&self, other: &MessageDeliveryTraceSnapshot) -> bool
fn eq(&self, other: &MessageDeliveryTraceSnapshot) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl<UT> TypeId<UT> for MessageDeliveryTraceSnapshot
impl<UT> TypeId<UT> for MessageDeliveryTraceSnapshot
impl Eq for MessageDeliveryTraceSnapshot
impl StructuralPartialEq for MessageDeliveryTraceSnapshot