pub struct MessageReactionSnapshot {
pub emoji: String,
pub count: u64,
pub reacted_by_me: bool,
}Fields
emoji: Stringcount: u64reacted_by_me: boolTrait Implementations
Sourceimpl Clone for MessageReactionSnapshot
impl Clone for MessageReactionSnapshot
Sourcefn clone(&self) -> MessageReactionSnapshot
fn clone(&self) -> MessageReactionSnapshot
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<UT> ConvertError<UT> for MessageReactionSnapshot
impl<UT> ConvertError<UT> for MessageReactionSnapshot
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl Debug for MessageReactionSnapshot
impl Debug for MessageReactionSnapshot
Sourceimpl<'de> Deserialize<'de> for MessageReactionSnapshot
impl<'de> Deserialize<'de> for MessageReactionSnapshot
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<UT> FfiConverter<UT> for MessageReactionSnapshot
impl<UT> FfiConverter<UT> for MessageReactionSnapshot
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a MetadataBuffer.
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl<UT> Lift<UT> for MessageReactionSnapshot
impl<UT> Lift<UT> for MessageReactionSnapshot
Sourceimpl<UT> LiftRef<UT> for MessageReactionSnapshot
impl<UT> LiftRef<UT> for MessageReactionSnapshot
Sourceimpl<UT> LiftReturn<UT> for MessageReactionSnapshot
impl<UT> LiftReturn<UT> for MessageReactionSnapshot
Sourcetype ReturnType = <MessageReactionSnapshot as Lift<UT>>::FfiType
type ReturnType = <MessageReactionSnapshot as Lift<UT>>::FfiType
FFI return type for trait interfaces
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
Sourcefn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
Sourcefn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
Sourcefn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> Lower<UT> for MessageReactionSnapshot
impl<UT> Lower<UT> for MessageReactionSnapshot
type FfiType = <MessageReactionSnapshot as FfiConverter<UT>>::FfiType
fn lower(obj: Self) -> Self::FfiType
fn write(obj: Self, buf: &mut Vec<u8>)
Sourcefn lower_into_rust_buffer(obj: Self) -> RustBuffer
fn lower_into_rust_buffer(obj: Self) -> RustBuffer
Convenience method
Sourceimpl<UT> LowerError<UT> for MessageReactionSnapshot
impl<UT> LowerError<UT> for MessageReactionSnapshot
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for MessageReactionSnapshot
impl<UT> LowerReturn<UT> for MessageReactionSnapshot
Sourcetype ReturnType = <MessageReactionSnapshot as Lower<UT>>::FfiType
type ReturnType = <MessageReactionSnapshot as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
Sourcefn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
Sourceimpl PartialEq for MessageReactionSnapshot
impl PartialEq for MessageReactionSnapshot
Sourceimpl Serialize for MessageReactionSnapshot
impl Serialize for MessageReactionSnapshot
Sourceimpl<UT> TypeId<UT> for MessageReactionSnapshot
impl<UT> TypeId<UT> for MessageReactionSnapshot
impl Eq for MessageReactionSnapshot
impl StructuralPartialEq for MessageReactionSnapshot