pub struct NetworkStatusSnapshot {
pub relay_set_id: String,
pub relay_urls: Vec<String>,
pub relay_connections: Vec<RelayConnectionSnapshot>,
pub connected_relay_count: u64,
pub all_relays_offline_since_secs: Option<u64>,
pub syncing: bool,
pub pending_outbound_count: u64,
pub pending_group_control_count: u64,
pub recent_event_count: u64,
pub recent_log_count: u64,
pub last_debug_category: Option<String>,
pub last_debug_detail: Option<String>,
}Fields
relay_set_id: Stringrelay_urls: Vec<String>relay_connections: Vec<RelayConnectionSnapshot>connected_relay_count: u64all_relays_offline_since_secs: Option<u64>syncing: boolpending_outbound_count: u64pending_group_control_count: u64recent_event_count: u64recent_log_count: u64last_debug_category: Option<String>last_debug_detail: Option<String>Trait Implementations
Sourceimpl Clone for NetworkStatusSnapshot
impl Clone for NetworkStatusSnapshot
Sourcefn clone(&self) -> NetworkStatusSnapshot
fn clone(&self) -> NetworkStatusSnapshot
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<UT> ConvertError<UT> for NetworkStatusSnapshot
impl<UT> ConvertError<UT> for NetworkStatusSnapshot
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl Debug for NetworkStatusSnapshot
impl Debug for NetworkStatusSnapshot
Sourceimpl<UT> FfiConverter<UT> for NetworkStatusSnapshot
impl<UT> FfiConverter<UT> for NetworkStatusSnapshot
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a MetadataBuffer.
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl<UT> Lift<UT> for NetworkStatusSnapshot
impl<UT> Lift<UT> for NetworkStatusSnapshot
Sourceimpl<UT> LiftRef<UT> for NetworkStatusSnapshot
impl<UT> LiftRef<UT> for NetworkStatusSnapshot
Sourceimpl<UT> LiftReturn<UT> for NetworkStatusSnapshot
impl<UT> LiftReturn<UT> for NetworkStatusSnapshot
Sourcetype ReturnType = <NetworkStatusSnapshot as Lift<UT>>::FfiType
type ReturnType = <NetworkStatusSnapshot as Lift<UT>>::FfiType
FFI return type for trait interfaces
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
Sourcefn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
Sourcefn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
Sourcefn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> Lower<UT> for NetworkStatusSnapshot
impl<UT> Lower<UT> for NetworkStatusSnapshot
type FfiType = <NetworkStatusSnapshot as FfiConverter<UT>>::FfiType
fn lower(obj: Self) -> Self::FfiType
fn write(obj: Self, buf: &mut Vec<u8>)
Sourcefn lower_into_rust_buffer(obj: Self) -> RustBuffer
fn lower_into_rust_buffer(obj: Self) -> RustBuffer
Convenience method
Sourceimpl<UT> LowerError<UT> for NetworkStatusSnapshot
impl<UT> LowerError<UT> for NetworkStatusSnapshot
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for NetworkStatusSnapshot
impl<UT> LowerReturn<UT> for NetworkStatusSnapshot
Sourcetype ReturnType = <NetworkStatusSnapshot as Lower<UT>>::FfiType
type ReturnType = <NetworkStatusSnapshot as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
Sourcefn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
Sourceimpl PartialEq for NetworkStatusSnapshot
impl PartialEq for NetworkStatusSnapshot
Sourceimpl<UT> TypeId<UT> for NetworkStatusSnapshot
impl<UT> TypeId<UT> for NetworkStatusSnapshot
impl Eq for NetworkStatusSnapshot
impl StructuralPartialEq for NetworkStatusSnapshot