pub struct PeerProfileDebugSnapshot {
pub owner_pubkey_hex: String,
pub owner_npub: String,
pub roster_device_count: u64,
pub known_device_count: u64,
pub active_session_count: u64,
pub session_count: u64,
pub receiving_session_count: u64,
pub tracked_sender_count: u64,
pub recent_handshake_device_count: u64,
pub last_handshake_at_secs: Option<u64>,
pub tracked_for_messages: bool,
}Fields
owner_pubkey_hex: Stringowner_npub: Stringroster_device_count: u64known_device_count: u64active_session_count: u64session_count: u64receiving_session_count: u64tracked_sender_count: u64recent_handshake_device_count: u64last_handshake_at_secs: Option<u64>tracked_for_messages: boolTrait Implementations
Sourceimpl Clone for PeerProfileDebugSnapshot
impl Clone for PeerProfileDebugSnapshot
Sourcefn clone(&self) -> PeerProfileDebugSnapshot
fn clone(&self) -> PeerProfileDebugSnapshot
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<UT> ConvertError<UT> for PeerProfileDebugSnapshot
impl<UT> ConvertError<UT> for PeerProfileDebugSnapshot
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl Debug for PeerProfileDebugSnapshot
impl Debug for PeerProfileDebugSnapshot
Sourceimpl<UT> FfiConverter<UT> for PeerProfileDebugSnapshot
impl<UT> FfiConverter<UT> for PeerProfileDebugSnapshot
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a MetadataBuffer.
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl<UT> Lift<UT> for PeerProfileDebugSnapshot
impl<UT> Lift<UT> for PeerProfileDebugSnapshot
Sourceimpl<UT> LiftRef<UT> for PeerProfileDebugSnapshot
impl<UT> LiftRef<UT> for PeerProfileDebugSnapshot
Sourceimpl<UT> LiftReturn<UT> for PeerProfileDebugSnapshot
impl<UT> LiftReturn<UT> for PeerProfileDebugSnapshot
Sourcetype ReturnType = <PeerProfileDebugSnapshot as Lift<UT>>::FfiType
type ReturnType = <PeerProfileDebugSnapshot as Lift<UT>>::FfiType
FFI return type for trait interfaces
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
Sourcefn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
Sourcefn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
Sourcefn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> Lower<UT> for PeerProfileDebugSnapshot
impl<UT> Lower<UT> for PeerProfileDebugSnapshot
type FfiType = <PeerProfileDebugSnapshot as FfiConverter<UT>>::FfiType
fn lower(obj: Self) -> Self::FfiType
fn write(obj: Self, buf: &mut Vec<u8>)
Sourcefn lower_into_rust_buffer(obj: Self) -> RustBuffer
fn lower_into_rust_buffer(obj: Self) -> RustBuffer
Convenience method
Sourceimpl<UT> LowerError<UT> for PeerProfileDebugSnapshot
impl<UT> LowerError<UT> for PeerProfileDebugSnapshot
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for PeerProfileDebugSnapshot
impl<UT> LowerReturn<UT> for PeerProfileDebugSnapshot
Sourcetype ReturnType = <PeerProfileDebugSnapshot as Lower<UT>>::FfiType
type ReturnType = <PeerProfileDebugSnapshot as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
Sourcefn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
Sourceimpl PartialEq for PeerProfileDebugSnapshot
impl PartialEq for PeerProfileDebugSnapshot
Sourcefn eq(&self, other: &PeerProfileDebugSnapshot) -> bool
fn eq(&self, other: &PeerProfileDebugSnapshot) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl<UT> TypeId<UT> for PeerProfileDebugSnapshot
impl<UT> TypeId<UT> for PeerProfileDebugSnapshot
impl Eq for PeerProfileDebugSnapshot
impl StructuralPartialEq for PeerProfileDebugSnapshot